;; Quail package `chinese-punct-b5' generated by the command `titdic-convert'
;;	Date: Tue Sep 23 14:59:14 1997
;;	Original TIT dictionary file: Punct-b5.tit

;;; Comment:

;; Do byte-compile this file again after any modification.

;;; Start of the header of original TIT dictionary.

;; # HANZI input table for cxterm
;; # Generated from Punct-b5.cit by cit2tit
;; # To be used by cxterm, convert me to .cit format first
;; # .cit version 1
;; ENCODE:	BIG5
;; MULTICHOICE:	YES
;; PROMPT:	$(0&d'GTT&,!JO:X5>KHA!K(B
;; #
;; COMMENT Copyright 1991 by Yongguang Zhang.	(ygz@cs.purdue.edu)
;; COMMENT Permission to use/modify/copy for any purpose is hereby granted.
;; COMMENT Absolutely no fee and no warranties.
;; COMMENT
;; COMMENT use <CTRL-f> to move to the right
;; COMMENT use <CTRL-b> to move to the left
;; COMMENT Modify by Wei-Chung Hwang, OCT 15, 1992.
;; # define keys
;; VALIDINPUTKEY:	!"\043$%&'()*+,-./0123456789:;<=>?@[\134]^_`abcdefghijkl
;; VALIDINPUTKEY:	mnopqrstuvwxyz{|}~
;; SELECTKEY:	1\040
;; SELECTKEY:	2
;; SELECTKEY:	3
;; SELECTKEY:	4
;; SELECTKEY:	5
;; SELECTKEY:	6
;; SELECTKEY:	7
;; SELECTKEY:	8
;; SELECTKEY:	9
;; SELECTKEY:	0
;; BACKSPACE:	\010\177
;; DELETEALL:	\015\025
;; MOVERIGHT:	\006
;; MOVELEFT:	\002
;; REPEATKEY:	\020\022
;; # the following line must not be removed
;; BEGINDICTIONARY

;;; End of the header of original TIT dictionary.

;;; Code:

(require 'quail)

(quail-define-package "chinese-punct-b5" "Chinese-BIG5" "$(0O:(BB"
 t
"$(0&d'GTT&,!JO:X5>KHA!K(B
 Copyright 1991 by Yongguang Zhang.	(ygz@cs.purdue.edu)
 Permission to use/modify/copy for any purpose is hereby granted.
 Absolutely no fee and no warranties.

 use <CTRL-f> to move to the right
 use <CTRL-b> to move to the left
 Modify by Wei-Chung Hwang, OCT 15, 1992.
"
 '(("\C-?" . quail-delete-last-char)
   ("\C-M" . quail-abort-translation)
   ("\C-U" . quail-abort-translation)
  )  nil nil nil nil)

(quail-define-rules
;; #
("!"	"$(0!*!5(B")
("\""	"$(0!f!g!h!i!q(B")
("\043"	"$(0!l"-(B")
("$"	"$(0"d"l"f"g(B")
("%"	"$(0"h(B")
("&"	"$(0".!m(B")
("'"	"$(0!d!e!j!k(B")
("("	"$(0!>!F!^!@!H!V!Z!Y!](B")
(")"	"$(0!?!G!_!A!I!W![!X!\(B")
("*"	"$(0"/"2$T$O"E(B")
("+"	"$(0"0"?"4$V!U"F(B")
(","	"$(0!"!.!#!/(B")
("-"	"$(0"1"@"@!7"##9"D(B")
("."	"$(0!$!%!&!0!1!,!-"O"P"x"T(B")
("/"	"$(0"_"a"3"5"`"b(B")
("0"	"$(0#O%M%W%a#b#l(B")
("1"	"$(0#P%D%N%X#Y#c#m(B")
("2"	"$(0#Q%E%O%Y#Z#d#n(B")
("3"	"$(0#R%F%P%Z#[#e(B")
("4"	"$(0#S%G%Q%[#\#f(B")
("5"	"$(0#T%H%R%\#]#g(B")
("6"	"$(0#U%I%S%]#^#h(B")
("7"	"$(0#V%J%T%^#_#i(B")
("8"	"$(0#W%K%U%_#`#j(B")
("9"	"$(0#X%L%V%`#a#k(B")
(":"	"$(0!(!+!3(B")
(";"	"$(0!'!2(B")
("<"	"$(0!R"A!N!P!T"9(B")
("="	"$(0"8"C";"=">(B")
(">"	"$(0!S"B!O!Q!U":(B")
("?"	"$(0!)!4(B")
("@"	"$(0"i"T(B")
("["	"$(0!b!J!L(B")
("\134"	"$(0"`"b"_"a(B")
("]"	"$(0!c!K!M(B")
("^"	"$(0!T(B")
("_"	"$(0!;!=(B")
("`"	"$(0!d!e!j!k(B")
("graph"	"$(0#$#%#&#'#(#)#*#+#,#-#.#/#0#1#2#3#4#5#6#7#8#9#:#;#<#=#>#?#@#A#B#C#D#E#F#G#H#I#J#K#L#M#N(B")
("logo"	"$(0!n!o!p!q!r!s!t!u!v!w!x!y!z!{!|!}!~"!"""#"$"%"&"'"(")"*"+",(B")
("math"	"$(0"0"1"2"3"4"5"6"7"8"9":";"<"=">"?"@"A"B"C"D"E"F"G"H"I"J"K"L"M"N"O"P(B")
("symbol"	"$(0"R"Q"S"T"U"V"W"X"Y"Z"["\"]"^"_"`"a"b(B")
("unit"	"$(0"c"d"e"f"g"h"h"i"p"q"r"s"t"u"v"w"x"y"z"{"|"}"~#!#"##(B")
("{"	"$(0!`!B!D(B")
("|"	"$(0!6"^!:#:"](B")
("}"	"$(0!a!C!E(B")
("~"	"$(0!="D"<(B")
)
